@@ -51,9 +51,14 @@ package com.openexchange.mobile.api.facade.connectors.responses.mtos;
 
 import com.fasterxml.jackson.annotation.JsonProperty;
 
+import lombok.AccessLevel;
+import lombok.AllArgsConstructor;
+import lombok.NoArgsConstructor;
 import lombok.Value;
 
 @Value
+@AllArgsConstructor
+@NoArgsConstructor(force = true, access = AccessLevel.PRIVATE)
 public class ConfigMto {
 
     @JsonProperty("deletemail")
