@@ -77,11 +77,11 @@ public class WeakforceWrapperAuthenticationService implements AuthenticationServ
         try {
             AllowResponse response = callWeakforceAllow(credentials);
             policyReject = response != null && response.isRejected();
-            SessionData sessionData = null;
-            if (!policyReject) {
-                sessionData = wrappedService.authenticate(credentials);
-                loginSuccessful = true;
+            if (policyReject) {
+                throw ApiFacadeException.invalidCredentials();
             }
+            SessionData sessionData = wrappedService.authenticate(credentials);
+            loginSuccessful = true;
             return sessionData;
         } catch (ApiFacadeException e) {
             loginSuccessful = false;
